@@ -1006,7 +1006,7 @@ class Generator:
         if AXUtilities.is_sensitive(obj):
             return []
 
-        if self._script.utilities.is_spreadsheet_cell(obj):
+        if AXUtilities.is_editable(obj):
             return []
 
         if self._mode == "braille":
@@ -1094,6 +1094,10 @@ class Generator:
             return result
 
         text = AXText.get_all_text(obj)
+        if not text and AXUtilities.is_table_cell_or_header(obj) \
+           and AXUtilities.is_editable(obj):
+            text = " ".join(AXText.get_all_text(child) for child in AXObject.iter_children(obj))
+
         if text and "\ufffc" not in text:
             if not AXUtilities.is_editable(obj):
                 Generator.CACHED_TEXT[hash(obj)] = [text]
